@@ -1,18 +1,17 @@
 from __future__ import annotations
 
-import attr
 import email.utils
 import errno
-import io
 import os
-import requests
 import sys
-import tenacity
 import urllib.parse
 from abc import abstractmethod
 from datetime import date, datetime
 from typing import List, Optional
 
+import attr
+import requests
+import tenacity
 
 from .Line import Line
 
@@ -47,10 +46,9 @@ class InputSource:
 
         if sourceName == "-":
             return StdinInputSource(sourceName)
-        elif sourceName.startswith("https:"):
+        if sourceName.startswith("https:"):
             return UrlInputSource(sourceName)
-        else:
-            return FileInputSource(sourceName)
+        return FileInputSource(sourceName)
 
     @abstractmethod
     def __str__(self) -> str:
@@ -67,9 +65,7 @@ class InputSource:
 
     @abstractmethod
     def read(self) -> InputContent:
-        """Fully reads the source.
-        """
-        pass
+        """Fully reads the source."""
 
     def hasDirectory(self) -> bool:
         """Only some InputSources have a directory."""
@@ -79,7 +75,7 @@ class InputSource:
         """Suitable for passing to subprocess(cwd=)."""
         raise TypeError("{} instances don't have directories.".format(type(self)))
 
-    def relative(self, relativePath) -> Optional[InputSource]:
+    def relative(self, _) -> Optional[InputSource]:
         """Resolves relativePath relative to this InputSource.
 
         For example, InputSource("/foo/bar/baz.txt").relative("quux/fuzzy.txt")
@@ -90,17 +86,24 @@ class InputSource:
         return None
 
     def mtime(self) -> Optional[float]:
-        """Returns the last modification time of this source, if that's known.
-        """
+        """Returns the last modification time of this source, if that's known."""
         return None
 
-    def cheaplyExists(self, relativePath) -> Optional[bool]:
+    def cheaplyExists(self, _) -> Optional[bool]:
         """If it's cheap to determine, returns whether relativePath exists.
 
         Otherwise, returns None.
         """
         return None
 
+    def __getattr__(self, name):
+        """Hack to make pylint happy, since all the attrs are defined
+        on the subclasses that __new__ dynamically dispatches to.
+        See https://stackoverflow.com/a/60731663/455535
+        """
+        print(f"No member '{name}' contained in InputSource.")
+        return ""
+
 
 class StdinInputSource(InputSource):
     def __init__(self, sourceName: str):
@@ -128,9 +131,9 @@ class UrlInputSource(InputSource):
     @tenacity.retry(
         reraise=True,
         stop=tenacity.stop_after_attempt(3),
-        wait=tenacity.wait_random(1,2),
+        wait=tenacity.wait_random(1, 2),
     )
-    def _fetch(self, *args, **kwargs):
+    def _fetch(self):
         response = requests.get(self.sourceName, timeout=10)
         if response.status_code == 404:
             # This matches the OSErrors expected by older uses of
@@ -141,7 +144,7 @@ class UrlInputSource(InputSource):
         return response
 
     def read(self) -> InputContent:
-        response = self._fetch(self.sourceName)
+        response = self._fetch()
         date = None
         if "Date" in response.headers:
             # Use the response's Date header, although servers don't always set
@@ -163,7 +166,7 @@ class FileInputSource(InputSource):
         return self.sourceName
 
     def read(self) -> InputContent:
-        with io.open(self.sourceName, "r", encoding="utf-8") as f:
+        with open(self.sourceName, encoding="utf-8") as f:
             return InputContent(
                 f.readlines(),
                 datetime.fromtimestamp(os.path.getmtime(self.sourceName)).date(),
@@ -182,8 +185,7 @@ class FileInputSource(InputSource):
         return os.access(self.relative(relativePath).sourceName, os.R_OK)
 
     def mtime(self) -> Optional[float]:
-        """Returns the last modification time of this file, or None if it doesn't exist.
-        """
+        """Returns the last modification time of this file, or None if it doesn't exist."""
         try:
             return os.stat(self.sourceName).st_mtime
         except FileNotFoundError:
