@@ -1,46 +1,51 @@
-# -*- coding: utf-8 -*-
-
-
 import glob
-import io
-import sys
 import os
-from collections import defaultdict, OrderedDict
-from datetime import datetime
-
-from . import biblio
-from . import boilerplate
-from . import caniuse
-from . import dfns
-from . import mdnspeclinks
-from . import conditional
-from . import config
-from . import constants
-from . import datablocks
-from . import extensions
-from . import fingerprinting
-from . import headings
-from . import highlight
-from . import h
-from . import idl
-from . import includes
-from . import inlineTags
-from . import lint
-from . import markdown
-from . import metadata
-from . import shorthands
-from . import wpt
+import sys
+from collections import defaultdict
+from functools import partial as curry
 
+from . import (
+    biblio,
+    boilerplate,
+    caniuse,
+    conditional,
+    config,
+    constants,
+    datablocks,
+    dfns,
+    extensions,
+    fingerprinting,
+    h,
+    headings,
+    highlight,
+    idl,
+    includes,
+    inlineTags,
+    lint,
+    markdown,
+    mdnspeclinks,
+    metadata,
+    shorthands,
+    wpt,
+)
+from .func import Functor
 from .h import *
-from .InputSource import InputSource, FileInputSource, StdinInputSource
-from .Line import Line
+from .InputSource import FileInputSource, InputSource
 from .messages import *
 from .refs import ReferenceManager
 from .unsortedJunk import *
 
-class Spec(object):
 
-    def __init__(self, inputFilename, debug=False, token=None, lineNumbers=False, fileRequester=None, testing=False):
+class Spec:
+    def __init__(
+        self,
+        inputFilename,
+        debug=False,
+        token=None,
+        lineNumbers=False,
+        fileRequester=None,
+        testing=False,
+    ):
         self.valid = False
         self.lineNumbers = lineNumbers
         if lineNumbers:
@@ -48,8 +53,10 @@ class Spec(object):
             constants.dryRun = True
         if inputFilename is None:
             inputFilename = findImplicitInputFile()
-        if inputFilename is None: # still
-            die("No input file specified, and no *.bs or *.src.html files found in current directory.\nPlease specify an input file, or use - to pipe from STDIN.")
+        if inputFilename is None:  # still
+            die(
+                "No input file specified, and no *.bs or *.src.html files found in current directory.\nPlease specify an input file, or use - to pipe from STDIN."
+            )
             return
         self.inputSource = InputSource(inputFilename)
         self.transitiveDependencies = set()
@@ -61,13 +68,25 @@ class Spec(object):
         else:
             self.dataFile = fileRequester
 
+        self.md = None
+        self.mdBaseline = None
+        self.mdDocument = None
+        self.mdCommandLine = None
+        self.mdDefaults = None
+        self.mdOverridingDefaults = None
+        self.lines = []
+        self.document = None
+        self.html = None
+        self.head = None
+        self.body = None
+        self.fillContainers = None
         self.valid = self.initializeState()
 
     def initializeState(self):
         self.normativeRefs = {}
         self.informativeRefs = {}
         self.refs = ReferenceManager(fileRequester=self.dataFile, testing=self.testing)
-        self.externalRefsUsed = defaultdict(lambda:defaultdict(dict))
+        self.externalRefsUsed = defaultdict(lambda: defaultdict(dict))
         self.md = None
         self.mdBaseline = metadata.MetadataManager()
         self.mdDocument = None
@@ -83,12 +102,12 @@ class Spec(object):
         self.testSuites = json.loads(self.dataFile.fetch("test-suites.json", str=True))
         self.languages = json.loads(self.dataFile.fetch("languages.json", str=True))
         self.extraStyles = defaultdict(str)
-        self.extraStyles['style-colors'] = styleColors
-        self.extraStyles['style-darkmode'] = styleDarkMode
-        self.extraStyles['style-md-lists'] = styleMdLists
-        self.extraStyles['style-autolinks'] = styleAutolinks
-        self.extraStyles['style-selflinks'] = styleSelflinks
-        self.extraStyles['style-counters'] = styleCounters
+        self.extraStyles["style-colors"] = styleColors
+        self.extraStyles["style-darkmode"] = styleDarkMode
+        self.extraStyles["style-md-lists"] = styleMdLists
+        self.extraStyles["style-autolinks"] = styleAutolinks
+        self.extraStyles["style-selflinks"] = styleSelflinks
+        self.extraStyles["style-counters"] = styleCounters
         self.extraScripts = defaultdict(str)
 
         try:
@@ -96,10 +115,13 @@ class Spec(object):
             self.lines = inputContent.lines
             if inputContent.date is not None:
                 self.mdBaseline.addParsedData("Date", inputContent.date)
-        except OSError:
-            die("Couldn't find the input file at the specified location '{0}'.", self.inputSource)
+        except FileNotFoundError:
+            die(
+                "Couldn't find the input file at the specified location '{0}'.",
+                self.inputSource,
+            )
             return False
-        except IOError:
+        except OSError:
             die("Couldn't open the input file '{0}'.", self.inputSource)
             return False
 
@@ -125,14 +147,30 @@ class Spec(object):
         # First load the metadata sources from 'local' data
         self.md = metadata.join(self.mdBaseline, self.mdDocument, self.mdCommandLine)
         # Using that to determine the Group and Status, load the correct defaults.include boilerplate
-        self.mdDefaults = metadata.fromJson(data=config.retrieveBoilerplateFile(self, 'defaults', error=True), source="defaults")
-        self.md = metadata.join(self.mdBaseline, self.mdDefaults, self.mdDocument, self.mdCommandLine)
+        self.mdDefaults = metadata.fromJson(
+            data=config.retrieveBoilerplateFile(self, "defaults", error=True),
+            source="defaults",
+        )
+        self.md = metadata.join(
+            self.mdBaseline, self.mdDefaults, self.mdDocument, self.mdCommandLine
+        )
         # Using all of that, load up the text macros so I can sub them into the computed-metadata file.
         self.md.fillTextMacros(self.macros, doc=self)
-        jsonEscapedMacros = {k: json.dumps(v)[1:-1] for k,v in self.macros.items()}
-        computedMdText = replaceMacros(config.retrieveBoilerplateFile(self, 'computed-metadata', error=True), macros=jsonEscapedMacros)
-        self.mdOverridingDefaults = metadata.fromJson(data=computedMdText, source="computed-metadata")
-        self.md = metadata.join(self.mdBaseline, self.mdDefaults, self.mdOverridingDefaults, self.mdDocument, self.mdCommandLine)
+        jsonEscapedMacros = {k: json.dumps(v)[1:-1] for k, v in self.macros.items()}
+        computedMdText = replaceMacros(
+            config.retrieveBoilerplateFile(self, "computed-metadata", error=True),
+            macros=jsonEscapedMacros,
+        )
+        self.mdOverridingDefaults = metadata.fromJson(
+            data=computedMdText, source="computed-metadata"
+        )
+        self.md = metadata.join(
+            self.mdBaseline,
+            self.mdDefaults,
+            self.mdOverridingDefaults,
+            self.mdDocument,
+            self.mdCommandLine,
+        )
         # Finally, compute the "implicit" things.
         self.md.computeImplicitMetadata(doc=self)
         # And compute macros again, in case the preceding steps changed them.
@@ -146,13 +184,18 @@ class Spec(object):
 
         # Deal with further <pre> blocks, and markdown
         self.lines = datablocks.transformDataBlocks(self, self.lines)
-        self.lines = markdown.parse(self.lines, self.md.indent, opaqueElements=self.md.opaqueElements, blockElements=self.md.blockElements)
+        self.lines = markdown.parse(
+            self.lines,
+            self.md.indent,
+            opaqueElements=self.md.opaqueElements,
+            blockElements=self.md.blockElements,
+        )
         # Note that, currently, markdown.parse returns an array of strings, not of Line objects.
 
         self.refs.setSpecData(self.md)
 
         # Convert to a single string of html now, for convenience.
-        self.html = ''.join(l.text for l in self.lines)
+        self.html = "".join(line.text for line in self.lines)
         boilerplate.addHeaderFooter(self)
         self.html = self.fixText(self.html)
 
@@ -249,18 +292,25 @@ class Spec(object):
             # Ensure that all W3C links are https.
             for el in findAll("a", self):
                 href = el.get("href", "")
-                if href.startswith("http://www.w3.org") or href.startswith("http://lists.w3.org"):
+                if href.startswith("http://www.w3.org") or href.startswith(
+                    "http://lists.w3.org"
+                ):
                     el.set("href", "https" + href[4:])
                 text = el.text or ""
-                if text.startswith("http://www.w3.org") or text.startswith("http://lists.w3.org"):
+                if text.startswith("http://www.w3.org") or text.startswith(
+                    "http://lists.w3.org"
+                ):
                     el.text = "https" + text[4:]
-            extensions.BSPrepTR(self)
+            # Loaded from .include files
+            extensions.BSPrepTR(self)  # pylint: disable=no-member
 
         return self
 
     def serialize(self):
         try:
-            rendered = h.Serializer(self.md.opaqueElements, self.md.blockElements).serialize(self.document)
+            rendered = h.Serializer(
+                self.md.opaqueElements, self.md.blockElements
+            ).serialize(self.document)
         except Exception as e:
             die("{0}", e)
         rendered = finalHackyCleanup(rendered)
@@ -288,16 +338,22 @@ class Spec(object):
                 if outputFilename == "-":
                     sys.stdout.write(rendered)
                 else:
-                    with io.open(outputFilename, "w", encoding="utf-8", newline=newline) as f:
+                    with open(
+                        outputFilename, "w", encoding="utf-8", newline=newline
+                    ) as f:
                         f.write(rendered)
             except Exception as e:
-                die("Something prevented me from saving the output document to {0}:\n{1}", outputFilename, e)
+                die(
+                    "Something prevented me from saving the output document to {0}:\n{1}",
+                    outputFilename,
+                    e,
+                )
 
     def printResultMessage(self):
         # If I reach this point, I've succeeded, but maybe with reservations.
-        fatals = messageCounts['fatal']
-        links = messageCounts['linkerror']
-        warnings = messageCounts['warning']
+        fatals = messageCounts["fatal"]
+        links = messageCounts["linkerror"]
+        warnings = messageCounts["warning"]
         if self.lineNumbers:
             warn("Because --line-numbers was used, no output was saved.")
         if fatals:
@@ -315,7 +371,7 @@ class Spec(object):
 
         outputFilename = self.fixMissingOutputFilename(outputFilename)
         if self.inputSource.mtime() is None:
-            die("Watch mode doesn't support {}".format(self.inputSource))
+            die(f"Watch mode doesn't support {self.inputSource}")
         if outputFilename == "-":
             die("Watch mode doesn't support streaming to STDOUT.")
             return
@@ -327,15 +383,16 @@ class Spec(object):
             import threading
 
             class SilentServer(http.server.SimpleHTTPRequestHandler):
-                def log_message(*args):
+                def log_message(self, format, *args):
                     pass
 
             socketserver.TCPServer.allow_reuse_address = True
             server = socketserver.TCPServer(
-              ("localhost" if localhost else "", port), SilentServer)
+                ("localhost" if localhost else "", port), SilentServer
+            )
 
-            print("Serving at port {0}".format(port))
-            thread = threading.Thread(target = server.serve_forever)
+            print(f"Serving at port {port}")
+            thread = threading.Thread(target=server.serve_forever)
             thread.daemon = True
             thread.start()
         else:
@@ -346,23 +403,28 @@ class Spec(object):
         try:
             self.preprocess()
             self.finish(outputFilename)
-            lastInputModified = {dep: dep.mtime()
-                                 for dep in self.transitiveDependencies}
+            lastInputModified = {
+                dep: dep.mtime() for dep in self.transitiveDependencies
+            }
             p("==============DONE==============")
             try:
                 while True:
                     # Comparing mtimes with "!=" handles when a file starts or
                     # stops existing, and it's fine to rebuild if an mtime
                     # somehow gets older.
-                    if any(input.mtime() != lastModified for input, lastModified in lastInputModified.items()):
+                    if any(
+                        input.mtime() != lastModified
+                        for input, lastModified in lastInputModified.items()
+                    ):
                         resetSeenMessages()
                         p("Source file modified. Rebuilding...")
                         self.initializeState()
                         self.mdCommandLine = mdCommandLine
                         self.preprocess()
                         self.finish(outputFilename)
-                        lastInputModified = {dep: dep.mtime()
-                                             for dep in self.transitiveDependencies}
+                        lastInputModified = {
+                            dep: dep.mtime() for dep in self.transitiveDependencies
+                        }
                         p("==============DONE==============")
                     time.sleep(1)
             except KeyboardInterrupt:
@@ -383,7 +445,7 @@ class Spec(object):
         if "markdown" in self.md.markupShorthands:
             textFunctor = MarkdownCodeSpans(text)
         else:
-            textFunctor = func.Functor(text)
+            textFunctor = Functor(text)
 
         macros = dict(self.macros, **moreMacros)
         textFunctor = textFunctor.map(curry(replaceMacros, macros=macros))
@@ -410,8 +472,9 @@ class Spec(object):
             return True
         return False
 
+
 def findImplicitInputFile():
-    '''
+    """
     Find what input file the user *probably* wants to use,
     by scanning the current folder.
     In preference order:
@@ -419,9 +482,8 @@ def findImplicitInputFile():
     2. Overview.bs
     3. the first file with a .bs extension
     4. the first file with a .src.html extension
-    '''
-    import glob
-    import os
+    """
+
     if os.path.isfile("index.bs"):
         return "index.bs"
     if os.path.isfile("Overview.bs"):
@@ -437,9 +499,10 @@ def findImplicitInputFile():
 
     return None
 
+
 constants.specClass = Spec
 
-styleColors = '''
+styleColors = """
 /* Any --*-text not paired with a --*-bg is assumed to have a transparent bg */
 :root {
     color-scheme: light dark;
@@ -546,9 +609,9 @@ styleColors = '''
     --outdated-shadow: red;
 
     --editedrec-bg: darkorange;
-}'''
+}"""
 
-styleDarkMode = '''
+styleDarkMode = """
 @media (prefers-color-scheme: dark) {
     :root {
         --text: #ddd;
@@ -659,9 +722,9 @@ styleDarkMode = '''
     /* In case a transparent-bg image doesn't expect to be on a dark bg,
        which is quite common in practice... */
     img { background: white; }
-}'''
+}"""
 
-styleMdLists = '''
+styleMdLists = """
 /* This is a weird hack for me not yet following the commonmark spec
    regarding paragraph and lists. */
 [data-md] > :first-child {
@@ -669,9 +732,9 @@ styleMdLists = '''
 }
 [data-md] > :last-child {
     margin-bottom: 0;
-}'''
+}"""
 
-styleAutolinks = '''
+styleAutolinks = """
 .css.css, .property.property, .descriptor.descriptor {
     color: var(--a-normal-text);
     font-size: inherit;
@@ -731,9 +794,9 @@ pre .property::before, pre .property::after {
 
 [data-link-type=biblio] {
     white-space: pre;
-}'''
+}"""
 
-styleSelflinks = '''
+styleSelflinks = """
 :root {
     --selflink-text: white;
     --selflink-bg: gray;
@@ -783,8 +846,8 @@ dfn > a.self-link:hover {
 a.self-link::before            { content: "¶"; }
 .heading > a.self-link::before { content: "§"; }
 dfn > a.self-link::before      { content: "#"; }
-'''
-styleDarkMode += '''
+"""
+styleDarkMode += """
 @media (prefers-color-scheme: dark) {
     :root {
         --selflink-text: black;
@@ -792,10 +855,10 @@ styleDarkMode += '''
         --selflink-hover-text: white;
     }
 }
-'''
+"""
 
 
-styleCounters = '''
+styleCounters = """
 body {
     counter-reset: example figure issue;
 }
@@ -822,4 +885,4 @@ figcaption {
 }
 figcaption:not(.no-marker)::before {
     content: "Figure " counter(figure) " ";
-}'''
+}"""
