@@ -3,15 +3,18 @@ import re
 from .. import config
 from ..h import E, outerHTML
 from ..messages import die
-
 from . import steps
 
+
 class ElementShorthand:
     def __init__(self):
         self.stage = "start"
         self.escapedText = None
         self.linkText = []
         self.bsAutolink = ""
+        self.linkFor = None
+        self.lt = None
+        self.linkType = None
 
     def respond(self, match, dom=None):
         if self.stage == "start":
@@ -48,37 +51,42 @@ class ElementShorthand:
             self.stage = "end"
             return steps.NextLiteral(endRe)
 
-    def respondLinkText(self, match, dom):
+    def respondLinkText(self, match, dom):  # pylint: disable=unused-argument
         self.linkText = dom
         self.bsAutolink += outerHTML(dom)
         return self.respondEnd()
 
     def respondEnd(self):
         if self.escapedText:
-            return steps.Success(skips=["<"], nodes=[self.escapedText[1:], *self.linkText, "}>"])
+            return steps.Success(
+                skips=["<"], nodes=[self.escapedText[1:], *self.linkText, "}>"]
+            )
 
         self.bsAutolink += "}>"
 
         if self.linkType not in config.markupTypes and self.linkType != "element-sub":
-            die("Shorthand {0} gives type as '{1}', but only markup types ({2}) are allowed.",
+            die(
+                "Shorthand {0} gives type as '{1}', but only markup types ({2}) are allowed.",
                 self.bsAutolink,
                 self.linkType,
-                config.englishFromList(config.idlTypes))
+                config.englishFromList(config.idlTypes),
+            )
             return steps.Success(E.span({}, self.bsAutolink))
 
         if not self.linkText:
             self.linkText = self.lt
 
         attrs = {
-            "data-link-type":self.linkType,
-            "for":self.linkFor,
-            "lt":self.lt,
-            "bs-autolink-syntax":self.bsAutolink}
-        return steps.Success(
-            E.a(attrs, linkText))
+            "data-link-type": self.linkType,
+            "for": self.linkFor,
+            "lt": self.lt,
+            "bs-autolink-syntax": self.bsAutolink,
+        }
+        return steps.Success(E.a(attrs, self.linkText))
 
 
-ElementShorthand.startRe = re.compile(r"""
+ElementShorthand.startRe = re.compile(
+    r"""
                         (?P<escape>\\)?
                         <{
                         (?P<element>[\w*-]+)
@@ -87,6 +95,8 @@ ElementShorthand.startRe = re.compile(r"""
                             (?:/(?P<value>[^}!|]+))?
                         )?
                         (?:!!(?P<linkType>[\w-]+))?
-                        (?P<linkText>\|)?""", re.X)
+                        (?P<linkText>\|)?""",
+    re.X,
+)
 
 endRe = re.compile("}>")
